"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var TokenType_1 = __importDefault(require("./TokenType"));
var isAlphaNumeric = function (str) {
    if (!str) {
        return false;
    }
    var regExp = /^[A-Za-z0-9\-#]+$/;
    return (str.match(regExp));
};
var Lexer = /** @class */ (function () {
    function Lexer(text) {
        var _this = this;
        this.text = text;
        this.index = 0;
        this.nextToken = function () {
            var ch = _this.text[_this.index];
            if (_this.index > _this.text.length) {
                return null;
            }
            if (isAlphaNumeric(ch)) {
                var ret = '';
                while (isAlphaNumeric(ch)) {
                    ret += ch;
                    _this.index++;
                    ch = _this.text[_this.index];
                }
                var token = {
                    value: ret,
                    tokenType: TokenType_1.default.TEXT
                };
                return token;
            }
            if (_this.isWhitespaceChar(ch)) {
                var ret = '';
                while (_this.isWhitespaceChar(ch)) {
                    ret += ch;
                    _this.index++;
                    ch = _this.text[_this.index];
                }
                var token = {
                    value: ret,
                    tokenType: TokenType_1.default.WHITESPACE
                };
                return token;
            }
            if (_this.text.slice(_this.index, _this.index + 2) === TokenType_1.default.END_TAG) {
                _this.index += 2;
                var token = {
                    value: TokenType_1.default.END_TAG,
                    tokenType: TokenType_1.default.END_TAG
                };
                return token;
            }
            else if (ch === "\/") {
                _this.index += 1;
                var token = {
                    value: ch || '',
                    tokenType: TokenType_1.default.TEXT
                };
                return token;
            }
            if (Object.values(TokenType_1.default).find(function (type) { return type === ch; })) {
                _this.index++;
                var token = {
                    tokenType: Object.values(TokenType_1.default).find(function (type) { return type === ch; }),
                    value: ch
                };
                return token;
            }
            {
                if (!ch) {
                    return null;
                }
                _this.index++;
                var token = {
                    value: ch,
                    tokenType: TokenType_1.default.TEXT
                };
                return token;
            }
            return null;
        };
        this.nextChar = function () {
            var peek = _this.peekChar();
            if (peek)
                _this.index += peek.length;
            return peek || '';
        };
        this.peekChar = function () {
            if (_this.index < _this.text.length) {
                var str_1 = _this.text[_this.index];
                Object.values(TokenType_1.default).find(function (type) {
                    if (type !== TokenType_1.default.TEXT && type !== TokenType_1.default.WHITESPACE) {
                        if (_this.text.slice(_this.index).startsWith(type)) {
                            str_1 = type;
                        }
                    }
                });
                return str_1;
            }
            return null;
        };
        this.isTextChar = function (ch) {
            if (!ch) {
                return false;
            }
            if (Object.values(TokenType_1.default).some(function (type) { return type === ch; }) || _this.isWhitespaceChar(ch)) {
                return false;
            }
            return true;
        };
        this.isWhitespaceChar = function (ch) {
            if (!ch) {
                return false;
            }
            switch (ch) {
                case " ":
                case "\t":
                case "\r":
                case "\n":
                    return true;
                default:
                    return false;
            }
        };
    }
    return Lexer;
}());
exports.default = Lexer;
//# sourceMappingURL=Lexer.js.map